
#ifndef _C11_ev539_
#define _C11_ev539_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1181_11121(EIF_REFERENCE);
extern void EIF_Minit539(void);
extern long O11091[];
extern long O8398[];

#ifdef __cplusplus
}
#endif

#endif
